InterruptReason

Struct InterruptReason 

pub struct InterruptReason {
    pub rx: bool,
    pub tx: bool,
    pub dma_error: bool,
    pub time_passed: bool,
}
A summary of the reasons for the occurence of an interrupt

Fields

rx: bool

A packet has arrived and is ready for processing.

tx: bool

A packet was sent, and a TX slot has freed up.

dma_error: bool

A DMA error occured.

time_passed: bool

The target time configured for PTP has passed.